pub enum CompilationOperationOutcome {
MissingExternalPackageFulfillment {
packages: Vec<PackageSpec>,
},
MismatchedExternalPackageTree {
spec: PackageSpec,
expected: PackageTreeIdentity,
actual: PackageTreeIdentity,
expected_file_count: u64,
actual_file_count: u64,
expected_byte_length: u64,
actual_byte_length: u64,
},
MalformedExternalPackageTree {
spec: PackageSpec,
path: String,
message: String,
},
MissingExternalFontFulfillment {
containers: Vec<FontContainerIdentity>,
},
MismatchedExternalFontContainer {
expected: FontContainerIdentity,
actual: FontContainerIdentity,
expected_length: u64,
actual_length: u64,
},
MalformedExternalFontContainer {
container: FontContainerIdentity,
index: u32,
},
}Expand description
A Pack-owned operational outcome before official compilation begins.
Variants
MissingExternalPackageFulfillment
The request supplied no authority for declared external packages.
Fields

packages: Vec<PackageSpec>MismatchedExternalPackageTree
Supplied files do not match the exact required Complete Package Tree.
MalformedExternalPackageTree
Supplied package files do not form a valid Complete Package Tree.
MissingExternalFontFulfillment
No fulfillment was supplied for declared external Font Containers.
Fields

containers: Vec<FontContainerIdentity>MismatchedExternalFontContainer
Supplied bytes do not match the exact required Font Container.
MalformedExternalFontContainer
Verified container bytes do not contain one declared face.