pub enum FilesystemMergePolicy {
WriteNewTree,
MergeCreateOnly,
MergeReplaceExactFiles,
}Expand description
An explicit policy for writing planned files to the filesystem.
Variants
WriteNewTree
Write a complete plan at an absent destination through one root commit.
MergeCreateOnly
Create every planned file and reject any existing planned target.
MergeReplaceExactFiles
Create missing planned files and atomically replace existing regular files.