#[non_exhaustive]pub enum FilesystemPackAssemblyClock {
System,
Fixed(DocumentTime),
}Expand description
Clock policy used when a run does not supply an exact Document Time.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
System
Resolve the current UNIX timestamp from the host clock for each run.
Fixed(DocumentTime)
Reuse one exact configured Document Time for every run.