#[non_exhaustive]pub enum PackInvariantIssue {
Show 20 variants
InvalidPath {
role: PackPathRole,
path: String,
message: String,
},
InvalidPackageSpec {
spec: String,
message: String,
},
InvalidPackageRequirement {
spec: String,
},
MismatchedEmbeddedPackageIdentity {
spec: String,
},
DuplicateProjectPath {
path: String,
},
DuplicatePackagePath {
package: PackageSpec,
path: String,
},
DuplicatePackageRequirement {
spec: String,
embedded: bool,
},
PathTreeConflict {
ancestor: String,
ancestor_role: PackPathRole,
descendant: String,
descendant_role: PackPathRole,
},
PackagePathTreeConflict {
package: String,
ancestor: String,
ancestor_role: PackPathRole,
descendant: String,
descendant_role: PackPathRole,
},
PackageRoleConflict {
spec: String,
},
UndeclaredPackageData {
spec: String,
},
MissingVendoredPackageData {
spec: String,
},
MissingFontData {
path: String,
},
InvalidFontData {
path: String,
index: u32,
},
InvalidExternalFontIdentity {
path: String,
},
MismatchedEmbeddedFontIdentity {
path: String,
},
InconsistentFontContainer {
path: String,
},
ExternalFontHasContainedData {
path: String,
},
DuplicateFontFace {
path: String,
index: u32,
},
MissingEntrypoint {
path: String,
},
}Expand description
One independently detectable violation of a whole-Pack invariant.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidPath
A path cannot identify a canonical file for its declared role.
InvalidPackageSpec
A package value cannot be represented as a canonical package specification.
InvalidPackageRequirement
A Package Requirement has a malformed or unsupported tree identity.
MismatchedEmbeddedPackageIdentity
Embedded package bytes disagree with their declared tree identity.
DuplicateProjectPath
Two project entries identify one canonical path.
DuplicatePackagePath
Two package entries identify one canonical path.
DuplicatePackageRequirement
One exact Package Requirement is declared more than once in one role.
PathTreeConflict
One file path is an ancestor of another file path in the same tree.
PackagePathTreeConflict
One package file path is an ancestor of another file path in that package.
PackageRoleConflict
A package was declared both vendored and unvendored.
UndeclaredPackageData
Package bytes exist without a matching vendored declaration.
MissingVendoredPackageData
A vendored package declaration has no contained bytes.
MissingFontData
A font declaration has no contained bytes.
InvalidFontData
Contained font bytes do not contain the declared face.
InvalidExternalFontIdentity
An external font declaration has no valid exact container identity.
MismatchedEmbeddedFontIdentity
Embedded font bytes disagree with their declared exact identity.
InconsistentFontContainer
Faces from one exact container disagree about its length or fulfillment role.
ExternalFontHasContainedData
An externally fulfilled declaration also has bytes in the Pack.
DuplicateFontFace
The same contained font face was declared more than once.
MissingEntrypoint
The declared entrypoint is not present among the packed project files.