#[non_exhaustive]pub enum PackageTreeIssue {
InvalidPath {
path: String,
message: String,
},
DuplicatePath {
path: String,
},
PathTreeConflict {
ancestor: String,
descendant: String,
},
}Expand description
One independently detectable issue in a supplied Package Tree.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidPath
A supplied path cannot name a package-relative file.
DuplicatePath
Two supplied entries name one canonical package file.
PathTreeConflict
One package file path is an ancestor of another package file path.