compile

Function compile 

pub fn compile(
    world: &dyn World,
    format: OutputFormat,
    options: &CompileOptions,
) -> Result<CompileOutput, CompileError>
Compiles the world’s document and exports it in the requested format.

This works with any World, but is intended for PackWorld.