#[non_exhaustive]pub enum PackageReadErrorCause {
ResolveOperator(Box<dyn Error + Send + Sync>),
UnsupportedTreeCapabilities {
list: bool,
list_with_recursive: bool,
read: bool,
},
UnsupportedArchiveRead,
TreeList(Error),
TreeRead(Error),
ListedTreeObjectAbsent(Error),
CacheRead(Error),
RegistryRead(Error),
TreeStructural(PackageTreeReadSurveyError),
InvalidPackageTree(PackageTreeError),
TreeLimit(PackageTreeReadLimitError),
ArchiveLimit(PackageArchiveReadLimitError),
}Expand description
The typed cause of a terminal OpenDAL Package Read failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ResolveOperator(Box<dyn Error + Send + Sync>)
The reached binding could not be resolved.
UnsupportedTreeCapabilities
A reached tree binding cannot recursively list or read selected files.
UnsupportedArchiveRead
A reached raw archive binding cannot read objects.
TreeList(Error)
A Package Tree recursive listing failed.
TreeRead(Error)
A listed Package Tree object read failed.
ListedTreeObjectAbsent(Error)
A listed Package Tree object became absent when read.
CacheRead(Error)
The raw Package Archive cache read failed.
RegistryRead(Error)
The official Package Registry read failed.
TreeStructural(PackageTreeReadSurveyError)
A completed Package Tree listing had envelope issues.
InvalidPackageTree(PackageTreeError)
Listed paths do not form a valid Package Tree.
TreeLimit(PackageTreeReadLimitError)
Package Tree Read exceeded a mandatory limit.
ArchiveLimit(PackageArchiveReadLimitError)
Raw Package Archive Read exceeded a mandatory limit.