pub struct FontReadSurveyError { /* private fields */ }Expand description
The nonempty canonical set of structural font survey issues.
Implementations
Sourceimpl FontReadSurveyError
impl FontReadSurveyError
Sourcepub fn issues(&self) -> &[FontReadIssue]
pub fn issues(&self) -> &[FontReadIssue]
Every independently detectable issue in source and path order.