pub struct CompilationArtifactWriteRequest { /* private fields */ }Expand description
A validated request to write every artifact in one succeeded Compilation Result.
Implementations
Sourceimpl CompilationArtifactWriteRequest
impl CompilationArtifactWriteRequest
Sourcepub fn new(
result: &CompilationResult,
destination: Location,
artifact_keys: impl IntoIterator<Item = impl Into<String>>,
policy: WritePolicy,
) -> Result<Self, CompilationArtifactWriteRequestRejection>
pub fn new( result: &CompilationResult, destination: Location, artifact_keys: impl IntoIterator<Item = impl Into<String>>, policy: WritePolicy, ) -> Result<Self, CompilationArtifactWriteRequestRejection>
Validates a prefix destination and one decoded relative key per canonical artifact.
pub const fn compilation_result_identity(&self) -> CanonicalIdentity
pub const fn destination(&self) -> &Location
pub fn artifact_keys(&self) -> &[String]
pub const fn policy(&self) -> WritePolicy