pub fn decode(
archive: &PackArchiveBytes,
limits: DecodeLimits,
) -> Result<Pack, DecodeError>Expand description
Decodes one borrowed exact Pack Archive into an authoritative Pack.
pub fn decode(
archive: &PackArchiveBytes,
limits: DecodeLimits,
) -> Result<Pack, DecodeError>Decodes one borrowed exact Pack Archive into an authoritative Pack.