pub fn open_pack(
path: impl AsRef<Path>,
read_limits: ReadLimits,
decode_limits: DecodeLimits,
) -> Result<Pack, OpenPackError>Expand description
Reads and decodes one Pack file while preserving exact bytes on decode failure.
pub fn open_pack(
path: impl AsRef<Path>,
read_limits: ReadLimits,
decode_limits: DecodeLimits,
) -> Result<Pack, OpenPackError>Reads and decodes one Pack file while preserving exact bytes on decode failure.