pub struct DiscoverySpecification { /* private fields */ }Expand description
The semantic controls for one Dependency Discovery run.
These values select dependencies for one Pack Creation invocation. They do not become Pack state and do not restrict later Pack compilation requests.
Implementations
Sourceimpl DiscoverySpecification
impl DiscoverySpecification
Sourcepub fn new(
target: TypstTarget,
inputs: Dict,
document_time: DocumentTime,
features: impl IntoIterator<Item = Feature>,
) -> Result<Self, DiscoverySpecificationError>
pub fn new( target: TypstTarget, inputs: Dict, document_time: DocumentTime, features: impl IntoIterator<Item = Feature>, ) -> Result<Self, DiscoverySpecificationError>
Validates and groups every semantic control for one discovery run.
Sourcepub fn target(&self) -> TypstTarget
pub fn target(&self) -> TypstTarget
The Typst document model selected for Dependency Discovery.
Sourcepub fn document_time(&self) -> DocumentTime
pub fn document_time(&self) -> DocumentTime
The exact or explicitly absent Document Time for this run.