pub struct EngineIdentity(/* private fields */);Expand description
The exact embedded Typst compiler implementation that produced a result.
Implementations
Sourceimpl EngineIdentity
impl EngineIdentity
Sourcepub fn implementation(self) -> &'static str
pub fn implementation(self) -> &'static str
The compiler crate used for semantic compilation.
Sourcepub fn source_checksum(self) -> &'static str
pub fn source_checksum(self) -> &'static str
The checksum of the exact compiler crate source from the Cargo lockfile.
Sourcepub fn target(self) -> &'static str
pub fn target(self) -> &'static str
The complete Rust target triple of the compiler implementation.
Sourcepub fn target_features(self) -> &'static str
pub fn target_features(self) -> &'static str
The target CPU features enabled for the compiler implementation.
Sourcepub fn feature_set(self) -> &'static str
pub fn feature_set(self) -> &'static str
The Cargo feature configuration of the compiler crate.
Sourcepub fn debug_assertions(self) -> bool
pub fn debug_assertions(self) -> bool
Whether the compiler implementation was built with debug assertions.