pub struct ImplementationIdentity { /* private fields */ }Expand description
The exact embedded implementation that participated in a result.
Implementations
Sourceimpl ImplementationIdentity
impl ImplementationIdentity
Sourcepub fn role(self) -> ImplementationRole
pub fn role(self) -> ImplementationRole
Whether this implementation is the engine or an exporter.
pub fn implementation(self) -> &'static str
pub fn version(self) -> &'static str
pub fn source_checksum(self) -> &'static str
pub fn target(self) -> &'static str
pub fn target_features(self) -> &'static str
pub fn feature_set(self) -> &'static str
pub fn debug_assertions(self) -> bool