pub struct LogicalSpan { /* private fields */ }Expand description
A source location expressed in the Pack’s logical namespace.
Implementations
Sourceimpl LogicalSpan
impl LogicalSpan
Sourcepub fn logical_path(&self) -> Option<&str>
pub fn logical_path(&self) -> Option<&str>
The logical project or package path, independent of transport location.
Sourcepub fn byte_range(&self) -> Option<&Range<usize>>
pub fn byte_range(&self) -> Option<&Range<usize>>
The exact source byte range when Typst attached one.