pub struct PackCompilationRequest { /* private fields */ }Expand description
An explicit semantic compilation request bound to one validated Pack.
Compilation through this request has no project, package, font, clock, environment, cache, or network fallback beyond the Pack and these values.
Implementations
Sourceimpl PackCompilationRequest
impl PackCompilationRequest
Sourcepub fn new(
pack: Pack,
output_specification: CompilationOutputSpecification,
) -> Self
pub fn new( pack: Pack, output_specification: CompilationOutputSpecification, ) -> Self
Binds a validated Pack to a tagged semantic output specification.
Sourcepub fn output(
self,
output_specification: CompilationOutputSpecification,
) -> Self
pub fn output( self, output_specification: CompilationOutputSpecification, ) -> Self
Sets caller-supplied output controls.
Sourcepub fn inputs(self, inputs: Dict) -> Self
pub fn inputs(self, inputs: Dict) -> Self
Sets the exact values exposed to document code as sys.inputs.
Sourcepub fn overrides(self, overrides: PackOverrideSet) -> Self
pub fn overrides(self, overrides: PackOverrideSet) -> Self
Applies one immutable Pack-bound Pack Override Set.
Sourcepub fn document_time(self, document_time: DocumentTime) -> Self
pub fn document_time(self, document_time: DocumentTime) -> Self
Sets the exact value returned by document-time requests.
Sourcepub fn fulfillments(self, fulfillments: CompilationFulfillmentSet) -> Self
pub fn fulfillments(self, fulfillments: CompilationFulfillmentSet) -> Self
Supplies the complete duplicate-free external fulfillment set.