PackWorld

Struct PackWorld 

pub struct PackWorld { /* private fields */ }
A complete Typst World backed by a Pack.

Project files and vendored package files come from the pack. Fonts come from the pack, plus any fonts configured on the builder. Files of packages that are not vendored are only available if a package loader is configured. Declared External Project Resources may come from external resource loaders; these loaders cannot replace packed files or supply Typst source or package files.

Implementations

Source

impl PackWorld

pub fn builder(pack: Pack) -> PackWorldBuilder

Starts configuring a world for the given pack.

pub fn new(pack: Pack) -> Result<Self, PackWorldError>

Creates a world with default configuration.

pub fn pack(&self) -> &Pack

The pack this world serves resources from.