pub struct PackageReadFailures { /* private fields */ }Expand description
Package Read Failures keyed by exact package specification.
Pack Assembly updates this value between Pack Creation invocations. A separately supplied Package Catalog entry always takes precedence during Dependency Discovery.
Implementations
Sourceimpl PackageReadFailures
impl PackageReadFailures
Sourcepub fn insert(
&mut self,
failure: PackageReadFailure,
) -> Option<PackageReadFailure>
pub fn insert( &mut self, failure: PackageReadFailure, ) -> Option<PackageReadFailure>
Records the latest failed attempt for one exact specification.
Sourcepub fn entries(&self) -> impl Iterator<Item = &PackageReadFailure>
pub fn entries(&self) -> impl Iterator<Item = &PackageReadFailure>
Failures in canonical exact-specification order.
Sourcepub fn get(&self, spec: &PackageSpec) -> Option<&PackageReadFailure>
pub fn get(&self, spec: &PackageSpec) -> Option<&PackageReadFailure>
Looks up the failed attempt for one exact specification.