pub struct PackageTree { /* private fields */ }Expand description
Every addressable regular file beneath one read package root.
Implementations
Sourceimpl PackageTree
impl PackageTree
Sourcepub fn from_owned_entries(
entries: impl IntoIterator<Item = (impl AsRef<str>, Vec<u8>)>,
) -> Result<Self, PackageTreeError>
pub fn from_owned_entries( entries: impl IntoIterator<Item = (impl AsRef<str>, Vec<u8>)>, ) -> Result<Self, PackageTreeError>
Constructs a tree by taking ownership of every file’s exact bytes.
Sourcepub fn copy_from_entries(
entries: impl IntoIterator<Item = (impl AsRef<str>, impl AsRef<[u8]>)>,
) -> Result<Self, PackageTreeError>
pub fn copy_from_entries( entries: impl IntoIterator<Item = (impl AsRef<str>, impl AsRef<[u8]>)>, ) -> Result<Self, PackageTreeError>
Constructs a tree by copying every file from caller-owned bytes.
Sourcepub fn files(&self) -> impl Iterator<Item = (&str, &[u8])>
pub fn files(&self) -> impl Iterator<Item = (&str, &[u8])>
The files in canonical package-relative path order.
Sourcepub fn file(&self, path: &str) -> Option<&[u8]>
pub fn file(&self, path: &str) -> Option<&[u8]>
Looks up a file by canonical package-relative path.
Sourcepub fn identity(&self) -> CanonicalIdentity
pub fn identity(&self) -> CanonicalIdentity
The Canonical Identity derived from every path and exact byte value.
Sourcepub fn file_count(&self) -> u64
pub fn file_count(&self) -> u64
The number of files in the tree.
Sourcepub fn byte_length(&self) -> u64
pub fn byte_length(&self) -> u64
The total exact byte length of every file in the tree.