pub fn extract(
pack: &Pack,
dir: &Path,
options: &ExtractOptions,
) -> Result<ExtractReport, ExtractError>Expand description
Writes the project files of a pack into a directory.
Project files are written directly into dir so that the result is a
compilable project. With packages and
fonts, the vendored packages and embedded fonts
are additionally written to packages/ and fonts/ subdirectories. The
manifest itself is not recreated; it lives only inside the archive.