pub struct PackWorldBuilder { /* private fields */ }Expand description
Configures a PackWorld.
Implementations
Sourceimpl PackWorldBuilder
impl PackWorldBuilder
Sourcepub fn inputs(self, inputs: Dict) -> Self
pub fn inputs(self, inputs: Dict) -> Self
Values made available to document code as sys.inputs.
Sourcepub fn feature(self, feature: Feature) -> Self
pub fn feature(self, feature: Feature) -> Self
Enables an experimental Typst language feature.
Feature::Html is required for compiling to
OutputFormat::Html.
Sourcepub fn fixed_date(self, datetime: Datetime) -> Self
pub fn fixed_date(self, datetime: Datetime) -> Self
Uses a fixed date for datetime.today(), for reproducible output.
Sourcepub fn extra_fonts<T: FontSource>(
self,
fonts: impl IntoIterator<Item = (T, FontInfo)>,
) -> Self
pub fn extra_fonts<T: FontSource>( self, fonts: impl IntoIterator<Item = (T, FontInfo)>, ) -> Self
Adds fonts on top of the ones embedded in the pack.
These rank behind pack fonts but before embedded default fonts, so use
this for system fonts or other host-provided fonts. Accepts the same
(source, info) entries yielded by the typst_kit::fonts providers,
so fonts are only loaded into memory when actually used.
Sourcepub fn package_loader(
self,
loader: impl FileLoader + Send + Sync + 'static,
) -> Self
pub fn package_loader( self, loader: impl FileLoader + Send + Sync + 'static, ) -> Self
Serves files of packages that are not vendored in the pack, e.g. from a package cache or the network.
Sourcepub fn external_resource_loader(
self,
loader: impl FileLoader + Send + Sync + 'static,
) -> Self
pub fn external_resource_loader( self, loader: impl FileLoader + Send + Sync + 'static, ) -> Self
Adds a loader for declared External Project Resources.
Loaders are tried in registration order after packed project files.
Sourcepub fn build(self) -> Result<PackWorld, PackWorldError>
pub fn build(self) -> Result<PackWorld, PackWorldError>
Builds the world.